#define SECTOR_SIZE 512

#include <stdlib.h>

#include "byte2sec.h"

/*
 *-----------------------------------------------------------------------------
 *
 * bytes2sectors --
 *
 * 	Takes a length and position in bytes, and allocates a buffer,
 * 	based on sector size to hold the other buffer.
 *
 * Results:
 *	Returns -1 on error, 0 if nothing is wrong.
 *
 * Side Effects:
 *
 *	Allocates a buffer that is usually freed by sector2bytes.
 *
 *-----------------------------------------------------------------------------
 */

int bytes2sectors (unsigned int bytelen, unsigned int inpos,
		   char **newbuf, unsigned int *sectorlen, unsigned int *outpos)
{
    int sector_offset = 0;

    sector_offset = inpos - (*outpos * SECTOR_SIZE);
    *outpos = inpos / SECTOR_SIZE;
    *sectorlen = ((bytelen + sector_offset) / SECTOR_SIZE) + 1;
    *newbuf = malloc(*sectorlen * SECTOR_SIZE);
    if (*newbuf == NULL) {
	diag_printf("Error malloc'ing %d bytes in bytes2sectors\n",
		    *sectorlen * SECTOR_SIZE);
	return -1;
    }
    return 0;
}

/*
 *-----------------------------------------------------------------------------
 *
 * sector2bytes --
 *
 * 	Takes a buffer in sector size chunks, and transfers it to a
 * 	'byte sized' buffer.
 *
 * Results:
 *	None.
 *
 * Side Effects:
 *
 *	Free's the sector-sized buffer.
 *
 *-----------------------------------------------------------------------------
 */

int sector2bytes (char *newbuf, unsigned int newpos,
		  char *oldbuf, unsigned int *oldlen, unsigned int oldpos)
{
    unsigned int sector_offset;

    sector_offset = oldpos - (newpos * SECTOR_SIZE);
    memcpy(oldbuf, newbuf + sector_offset, *oldlen);
    free(newbuf);
}
